==> common-login-4.11.0.20221012.030116-1-sources.jar: com/kuaike/scrm/dubbo/filter/ProviderTraceFilter.java <==
package com.kuaike.scrm.dubbo.filter;

import com.alibaba.dubbo.common.Constants;
import com.alibaba.dubbo.common.extension.Activate;
import com.alibaba.dubbo.rpc.*;
import com.kuaike.scrm.common.utils.LoginUtils;
import lombok.extern.slf4j.Slf4j;

/**
 * 在调用dubbo的rpc接口时，通过隐式传参把当前用户的sessionId传到服务端，以达成RPC服务间的session共享。
 *
 * https://blog.csdn.net/syslijian/article/details/106466933
 *
 */
@Slf4j
@Activate(group = {Constants.PROVIDER})
public class ProviderTraceFilter implements Filter {

    @Override
    public Result invoke(Invoker<?> invoker, Invocation invocation) throws RpcException {
        try {
            initSession(invocation);

            Result result = invoker.invoke(invocation);
            return result;
        } catch (RpcException e) {
            log.error("调用dubbo 接口异常，errorMsg:{}", e.getMessage());
            throw e;
        }
    }

    protected void initSession(Invocation invocation) {
        String sessionId = invocation.getAttachment("sessionId");
        String userIdStr = invocation.getAttachment("userId");
        if (sessionId == null || userIdStr == null) {
            return;
        }

        Long userId = Long.parseLong(userIdStr);
        log.debug("initialize rpc sessionId:{}, userId:{}", sessionId, userId);

        if (LoginUtils.REDIS_TEMPLATE != null) {
            LoginUtils.initRpcCurrentUser(sessionId, userId);
            log.debug("current user bizId:{}", LoginUtils.getCurrentUserBizId());
        } else {
            log.warn("redisTemplate is null");
        }
    }


}

==> common-login-4.30.0-20230515.120750-3-sources.jar: com/kuaike/scrm/dubbo/filter/ProviderTraceFilter.java <==
package com.kuaike.scrm.dubbo.filter;

import com.alibaba.dubbo.common.Constants;
import com.alibaba.dubbo.common.extension.Activate;
import com.alibaba.dubbo.rpc.*;
import com.kuaike.scrm.common.utils.LoginUtils;
import lombok.extern.slf4j.Slf4j;

/**
 * 在调用dubbo的rpc接口时，通过隐式传参把当前用户的sessionId传到服务端，以达成RPC服务间的session共享。
 *
 * https://blog.csdn.net/syslijian/article/details/106466933
 *
 */
@Slf4j
@Activate(group = {Constants.PROVIDER})
public class ProviderTraceFilter implements Filter {

    @Override
    public Result invoke(Invoker<?> invoker, Invocation invocation) throws RpcException {
        try {
            initSession(invocation);

            return invoker.invoke(invocation);
        } catch (RpcException e) {
            log.error("调用dubbo 接口异常，errorMsg:{}", e.getMessage());
            throw e;
        }
    }

    protected void initSession(Invocation invocation) {
        String sessionId = invocation.getAttachment("sessionId");
        String userIdStr = invocation.getAttachment("userId");
        if (sessionId == null || userIdStr == null) {
            return;
        }

        Long userId = Long.parseLong(userIdStr);
        log.debug("initialize rpc sessionId:{}, userId:{}", sessionId, userId);

        if (LoginUtils.getRedisTemplate() == null) {
            log.warn("redisTemplate is null");
        } else {
            LoginUtils.initRpcCurrentUser(sessionId, userId);
            log.debug("current user bizId:{}", LoginUtils.getCurrentUserBizId());
        }
    }


}
